@@ -51,12 +51,20 @@ class KNutClient : public QObject, public KSessionManaged {
     void slotPreferenceUps(void);
     void slotSetConfig (unsigned int changeSetting);
 
-    void slotPrintUPSVars();
-    void slotInstComms();
-    void slotRWVars();
+    void slotPrintUPSVars(void);
+    void slotInstComms(void);
+    void slotRWVars(void);
     void slotChangeRWVars( QString varName);
 
-    void slotExitApplication();
+    void slotExitApplication(void);
+
+/**
+ * .
+ *
+ * @since  0.1
+ **/
+    void slotRefreshConnection(void);
+
 
     void minimizeMainWindow (void);
     void exitMainWindow (void);
