@@ -403,6 +403,8 @@ void KNutDock::createMainMenu(void) {
   menu->insertItem(i18n("&Running instant commands"), this, SLOT(slotInstComms()));
   menu->insertItem(i18n("Setting R&W variables"), this, SLOT(slotRWVars()));
   menu->insertSeparator();
+  menu->insertItem(SmallIcon("reload"),i18n("Reconnect"), this, SLOT(slotRefreshConnection()));
+  menu->insertSeparator();
   menu->insertItem(SmallIcon("configure"),i18n("&Preferences"), this, SLOT(slotPreferences()));
   menu->insertSeparator();
   menu->insertItem(kapp->miniIcon(),i18n("&About KNutClient"), this, SLOT(showMyAbout()));
@@ -431,30 +433,42 @@ void KNutDock::slotExitApplication (void) {
   }
 
 void KNutDock::slotUpsName(int i) {
+
   emit UPSChanged(upsRecords->getName(i-101));
   }
 
 
 void KNutDock::slotMinimize(void) {
+
   emit minimize ();
   }
 
 void KNutDock::slotPreferences(void) {
+
   emit preferences();
   }
 
 void KNutDock::slotPrintUPSVars(void) {
+
   emit printUPSVars();
   }
 
 void KNutDock::slotInstComms(void) {
+
   emit instComms();
   }
 
 void KNutDock::slotRWVars(void) {
+
   emit RWVars();
   }
 
+void KNutDock::slotRefreshConnection(void) {
+
+  emit makeRefreshConnection();
+  }
+
+  
 //------------------------------------------
 
 void KNutDock::paintEvent (QPaintEvent *e) {
