@@ -41,7 +41,7 @@
 
 KNutFrontPanel::KNutFrontPanel( QPalette* const paletteIn, QWidget *parent, const unsigned int flags, QFont* const panelFonts, const char *name) : QFrame( parent, name ), panelFlags(flags) {
 
-  myPalette = *paletteIn;
+  myPalette = paletteIn->copy(); // We must make deep copy of palette
   upsOk = green;
   upsError = red;
   upsBack = white; //backgroundColor();
@@ -51,10 +51,9 @@ KNutFrontPanel::KNutFrontPanel( QPalette* const paletteIn, QWidget *parent, cons
 
   setFrameStyle( QFrame::Box | QFrame::Raised );
   setLineWidth( 2 );
-  setPalette (myPalette);
       
   if (panelFonts == 0) {
-    panelFont =kapp->font(); // nastavime font sytemovy font
+    panelFont =kapp->font(); // nastavime font systemovy font
     panelBoldFont = kapp->font();
     }
   else {
@@ -208,23 +207,17 @@ KNutFrontPanel::KNutFrontPanel( QPalette* const paletteIn, QWidget *parent, cons
   mainLayout->addStretch(20);
   mainLayout->addSpacing(5);
 
-  LCDPaletteOk = palette();
-  LCDPaletteErr = palette();
-
-  LCDPaletteOk = palette();
-  LCDPaletteErr = palette();
-
-  setLCDPalette ();
+  setAllPalettes();
 
   changePanelFont();
   paintPanel ();
+
   }
 
 KNutFrontPanel::~KNutFrontPanel(){
   }
 
 
-
 //************************************************************
 
 void KNutFrontPanel::paintPanel( void ) {
@@ -506,8 +499,8 @@ void KNutFrontPanel::slotSetPanelFont(QFont newPanelFont) {
   }
 
 void KNutFrontPanel::setLCDPalette (void) {
-  LCDPaletteOk = palette();
-  LCDPaletteErr = palette();
+  LCDPaletteOk = myPalette;
+  LCDPaletteErr = myPalette;
   //Nastavime barvu pro OK system je online
   QColorGroup activeColorGroup = LCDPaletteOk.active();
   activeColorGroup.setColor( QColorGroup::Foreground, green);
@@ -523,11 +516,18 @@ void KNutFrontPanel::setLCDPalette (void) {
 
   }
 
-  
 void KNutFrontPanel::setPalette (const QPalette & p){
-  QFrame::setPalette (p);
-  LCDPaletteOk = palette();
-  LCDPaletteErr = palette();
+
+  myPalette = p;
+  setAllPalettes();
+  }
+
+      
+void KNutFrontPanel::setAllPalettes (void){
+
+  QFrame::setPalette (myPalette);
+  LCDPaletteOk = myPalette;
+  LCDPaletteErr = myPalette;
 
   setLCDPalette();
   if (LCDNumber1) {
@@ -538,4 +538,6 @@ void KNutFrontPanel::setPalette (const QPalette & p){
     }
   }
 
+
+  
 #include "knutfrontpanel.moc"  
