@@ -214,18 +214,28 @@ class KNutFrontPanel : public QFrame  {
   private:
 
 /**
+ * @internal
  * Nastavi palety pro LCDPabel.
  *
  * @since  0.1
  */
   void setLCDPalette (void);
 
+/**
+ * @internal
+ * Provede zmenu paletty vsech prvku na zaklade promenne myPalette
+ *
+ * @since  0.1
+ */
+  void setAllPalettes (void);
+
+  void changePanelFont (void);
+
+
   static const int PanelTextTop = 8;
   static const int PanelTextBottom = 4;
   static const int PanelTextHigh = 25;
 
-  void changePanelFont (void);
-
   QLabel* textLabel1;
   QLabel* textLabel2;
   QLabel* textLabel3;
