@@ -35,6 +35,8 @@
 #include <qscrollview.h>
 #include <qlayout.h>
 
+#include <qiconset.h>
+
 #include <math.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -55,7 +57,6 @@ KNutMainWindow::KNutMainWindow(QStringList *tListKNutEvent, struct upsInfo* tAct
   listKNutEvent=tListKNutEvent;  
 
   initVars();
-  setPalette(mainPalette);
   initStatusBar();
   initAction();
 //  createGUI ("/home/dan/Projekty/knutclient/knutclient/knutclientui.rc"); // pred distribuci nezapomenou odstranit retezec
@@ -73,10 +74,12 @@ KNutMainWindow::KNutMainWindow(QStringList *tListKNutEvent, struct upsInfo* tAct
   // nastavime paletu pro analogove panely
   if (settingData->customBAnalogColor) {
     aPanelPalette.setColor(QPalette::Active,QColorGroup::Background,settingData->aPanelBackgroundColor);
+    aPanelPalette.setColor(QPalette::Inactive,QColorGroup::Background,settingData->aPanelBackgroundColor);
     }
 
  if (settingData->customBColor) {
     areaPalette.setColor(QPalette::Active,QColorGroup::Background,settingData->mainBackgroundColor);
+    areaPalette.setColor(QPalette::Inactive,QColorGroup::Background,settingData->mainBackgroundColor);
     }
 
   
@@ -91,6 +94,7 @@ KNutMainWindow::KNutMainWindow(QStringList *tListKNutEvent, struct upsInfo* tAct
   mainLayout->addWidget(mainSplit);
   if (settingData->customBPanelColor) {
     mPanelPalette.setColor(QPalette::Active,QColorGroup::Background,settingData->mPanelBackgroundColor);
+    mPanelPalette.setColor(QPalette::Inactive,QColorGroup::Background,settingData->mPanelBackgroundColor);
     }
 
   QScrollView* panelSV = new QScrollView(mainSplit,"panelSV");    
@@ -105,9 +109,7 @@ KNutMainWindow::KNutMainWindow(QStringList *tListKNutEvent, struct upsInfo* tAct
   panelMeter = new KNutPanelMeter(aPanelPalette,activeUpsInfo,settingData,analogRecords,mainSplit);
   mainSplit->setResizeMode (panelMeter,QSplitter::Stretch );
 
-  setPalette(areaPalette);
   area->setPalette(areaPalette);
-  frontPanel->setPalette(mPanelPalette);
   panelMeter->setPalette(areaPalette);
   
   // Nastavime COMBO  a pripadne aktivujeme spojeni na merici panely
@@ -117,8 +119,9 @@ KNutMainWindow::KNutMainWindow(QStringList *tListKNutEvent, struct upsInfo* tAct
   setGeometry (settingData->x,settingData->y,settingData->width,settingData->height);
   show();
 
-   // mesage musime vlozit do status baru az po zobrazeni okna,
+   // message musime vlozit do status baru az po zobrazeni okna,
   // jinak se nastavi minimalni velikost ne mensi nez delka aktivni zpravy.
+  // neplati pro kde => 3.x.x
   initStatusBarMessage();
   }
 
@@ -143,7 +146,7 @@ void KNutMainWindow::addComboStatusItem (const QString text, const QString name)
   }
 
 
-KNutMainWindow::~KNutMainWindow() {
+KNutMainWindow::~KNutMainWindow(void) {
 
   settingData->height = height();
   settingData->width = width();
@@ -155,20 +158,20 @@ KNutMainWindow::~KNutMainWindow() {
   }
 
 
-void KNutMainWindow::slotShowToolBar() {
+void KNutMainWindow::slotShowToolBar(void) {
   statusBar()->message(i18n("Toggle the toolbar..."),2000);
   if(toolBar("mainToolBar")->isVisible()) toolBar("mainToolBar")->hide();
   else toolBar("mainToolBar")->show();
   }
 
 
-void KNutMainWindow::slotShowStatusBar() {
+void KNutMainWindow::slotShowStatusBar(void) {
   statusBar()->message(i18n("Toggle the statusbar..."),2000);
   if(statusBar()->isVisible()) statusBar()->hide();
   else statusBar()->show();
   }
 
-void KNutMainWindow::slotDescription() {
+void KNutMainWindow::slotDescription(void) {
   if (descriptionAction->isChecked()) {
     if (!activeUpsInfo->upsNet->isDescription()) activeUpsInfo->upsNet->getDescription();
     settingData->useDescription=true;
@@ -178,22 +181,27 @@ void KNutMainWindow::slotDescription() {
 
 
 
-void KNutMainWindow::slotPrintUPSVars() {
+void KNutMainWindow::slotPrintUPSVars(void) {
 
   emit showUPSVars();
 }
 
 
-void KNutMainWindow::slotInstComms() {
+void KNutMainWindow::slotInstComms(void) {
 
   emit makeInstComms();
   }
 
-void KNutMainWindow::slotRWVars() {
+void KNutMainWindow::slotRWVars(void) {
 
   emit makeRWVars();
   }
 
+void KNutMainWindow::slotRefreshConnection(void) {
+
+  emit makeRefreshConnection();
+  }
+
 
 void KNutMainWindow::slotChangeRWVars ( QString varName) {
   }
@@ -210,16 +218,16 @@ void KNutMainWindow::setConfig (unsigned int changeSetting) {
   // Main Setting
 
   // Nastavime zmenu barvy pozadi
+  // We set background color
   if (changeSetting & knc::ChangeCustomBColor) {
-    if (!settingData->customBColor) { // nastavime barvu pozadi podle systemu
-      setPalette (mainPalette);
-      area->setPalette (mainPalette);
+    if (!settingData->customBColor) { // nastavime barvu pozadi podle systemu 
+      area->setPalette (mainPalette); // we set background color based on system
       panelMeter->setPalette (mainPalette);
       repaint();
       }
     else {
       areaPalette.setColor(QPalette::Active,QColorGroup::Background,settingData->mainBackgroundColor);
-      setPalette (areaPalette);
+      areaPalette.setColor(QPalette::Inactive,QColorGroup::Background,settingData->mainBackgroundColor);
       area->setPalette (areaPalette);
       panelMeter->setPalette (areaPalette);
       repaint();
@@ -228,7 +236,7 @@ void KNutMainWindow::setConfig (unsigned int changeSetting) {
   else {
     if (changeSetting & knc::ChangeMBColor ) {
       areaPalette.setColor(QPalette::Active,QColorGroup::Background,settingData->mainBackgroundColor);
-      setPalette (areaPalette);
+      areaPalette.setColor(QPalette::Inactive,QColorGroup::Background,settingData->mainBackgroundColor);
       area->setPalette (areaPalette);
       panelMeter->setPalette (areaPalette);
       repaint();
@@ -262,6 +270,7 @@ void KNutMainWindow::setConfig (unsigned int changeSetting) {
       }
     else {
     // XFER neni aktivovano nebo je nepodporuje UPS
+    // XFER isn;t activated or XFER isn't supported by UPS
     if ((changeSetting & knc::ChangeVoltage) || ((changeSetting & knc::ChangeXFer))) {
     // byla aktivovana zmena napeti nebo zmena xfer a zaroven ho ups podporuje
       analogRecords->setVoltage(settingData->inputVoltage);
@@ -276,10 +285,11 @@ void KNutMainWindow::setConfig (unsigned int changeSetting) {
   }
 
   // Analog setting
-  if ((changeSetting & knc::ChangeCustomAPanelBColor) || // je provedena zmena barvy panelu
+  if ((changeSetting & knc::ChangeCustomAPanelBColor) || // je provedena zmena barvy panelu, panel color is changed
       (changeSetting & knc::ChangeAPBColor)) {
   if (settingData->customBAnalogColor) {
     aPanelPalette.setColor(QPalette::Active,QColorGroup::Background,settingData->aPanelBackgroundColor);
+    aPanelPalette.setColor(QPalette::Inactive,QColorGroup::Background,settingData->aPanelBackgroundColor);
     repaintAllPanels=true;
     panelMeter->setAnalogBG(aPanelPalette);
     }
@@ -324,12 +334,14 @@ void KNutMainWindow::setConfig (unsigned int changeSetting) {
       }
     else {
       mPanelPalette.setColor(QPalette::Active,QColorGroup::Background,settingData->mPanelBackgroundColor);
+      mPanelPalette.setColor(QPalette::Inactive,QColorGroup::Background,settingData->mPanelBackgroundColor);
       frontPanel->setPalette (mPanelPalette);
       }
     }
   else {
     if (changeSetting & knc::ChangeMPBColor ) {
       mPanelPalette.setColor(QPalette::Active,QColorGroup::Background,settingData->mPanelBackgroundColor);
+      mPanelPalette.setColor(QPalette::Inactive,QColorGroup::Background,settingData->mPanelBackgroundColor);
       frontPanel->setPalette (mPanelPalette);
       }
     }
@@ -455,8 +467,10 @@ void KNutMainWindow::showUpsData (void) {
     panelMeter->deActivateAnalogs();
 
     // pokud je pouzito XFER nastavime hodnoty
+    // when XFER is used we set values
       if (settingData->lowHighXfer) {
         // xfer je nastaveno
+        // xfer is setting
         if (existLowHighXfer) {
           if (abs((int)(230 - (lowXfer + (highXfer  - lowXfer) /2))) > abs((int)(120 - (lowXfer + (highXfer  - lowXfer) /2)))) {
             analogRecords->setVoltage(120);
@@ -472,7 +486,6 @@ void KNutMainWindow::showUpsData (void) {
 
     panelMeter->activateAnalogs();
     panelMeter->setSize(true);
-//    panelMeter->resizeContents(panelMeter->sizeHint().width(),panelMeter->sizeHint().height());
     mainSplit->refresh();
     repaintAnalogs();
     }
@@ -480,7 +493,6 @@ void KNutMainWindow::showUpsData (void) {
     frontPanel->cleanPanel();
     panelMeter->deActivateAnalogs();
     panelMeter->setSize(false);
-//    panelMeter->resizeContents(panelMeter->sizeHint().width(),panelMeter->sizeHint().height());
     mainSplit->refresh();
     }
   }
@@ -518,7 +530,8 @@ void KNutMainWindow::repaintPanel (void) {
   }
 
 
-/// je volan vzdy po timeautu  
+/// je volan vzdy po timeautu
+/// this function is called after timeout always
 void KNutMainWindow::repaintAnalogs (void) {
   QString nutStringVar;
   float numVar;
@@ -598,16 +611,7 @@ void KNutMainWindow::initStatusBar ( void ) {
 
 void KNutMainWindow::initStatusBarMessage ( void ) {
   // naplnime combo
-  #if defined  (KDE_VERSION_MAJOR)
-    #if KDE_VERSION_MAJOR >= 3
-      QStringList::iterator it;
-    #else
-      QStringList::Iterator it;
-    #endif
-  #else
-      QStringList::Iterator it;
-  #endif
-
+  QStringList::iterator it;
 
   for ( it = listKNutEvent->begin(); it != listKNutEvent->end(); ++it ) {
     infoCombo->insertItem((*it));
@@ -618,6 +622,7 @@ void KNutMainWindow::initStatusBarMessage ( void ) {
   
 
 void KNutMainWindow::initToolBar ( void ) {
+
   QLabel *upsNazev = new QLabel ("UPS : ",toolBar("mainToolBar"));
   // upsNazev je navazan na toolBar neni potreba volat destruktor
   toolBar ("mainToolBar")->insertWidget (0,upsNazev->sizeHint().width(),upsNazev);
@@ -632,6 +637,8 @@ void KNutMainWindow::initToolBar ( void ) {
 
 
 void KNutMainWindow::initAction ( void ) {
+
+  // KAction and KStdAction must be to make before command createGUI, function initToolBar is runed after create GUI
   quit = KStdAction::quit (this, SLOT (slotCloseKnutClient()), actionCollection());
   quit->setStatusText(i18n("Quits the application"));
 
@@ -643,7 +650,7 @@ void KNutMainWindow::initAction ( void ) {
   KStdAction::showStatusbar (this, SLOT (slotShowStatusBar()), actionCollection());
   descriptionAction = new KToggleAction(i18n("&Using descriptions"),0,this,SLOT(slotDescription()),actionCollection(),"use_description");
   KStdAction::keyBindings( this, SLOT(slotConfigureKeys()),actionCollection());
-
+  new KAction (i18n("Reconnect"),"reload",Key_F5,this,SLOT(slotRefreshConnection()),actionCollection(),"reconnect");
   }
 
 void KNutMainWindow::initVars ( void ) {
@@ -651,6 +658,7 @@ void KNutMainWindow::initVars ( void ) {
   activeUpsIndex = -1;
 
   //nastavime fonty
+  // we are setting fonts
   mainPalette= kapp->palette();
   areaPalette=mainPalette;
   mPanelPalette=mainPalette;
@@ -659,7 +667,7 @@ void KNutMainWindow::initVars ( void ) {
 
 
 int KNutMainWindow::activeMainCombo (void) {
-  int activeUpsNameIndex = -1; // zadne upsName neni aktivni
+  int activeUpsNameIndex = -1; // zadne upsName neni aktivni , any upsName is not active
   KComboBox *combo = toolBar(0)->getCombo(1);
 
   //naplnime comboBox
@@ -667,6 +675,7 @@ int KNutMainWindow::activeMainCombo (void) {
   for (int i=0; i < upsRecords->getCount (); i++) {
     combo->insertItem (upsRecords->getName(i));
     // ulozime si poradove cislo jmena aktivniho ups
+    // save serial number of active usp name
     if ((upsRecords->getName(i)) == activeUpsInfo->record.name) activeUpsNameIndex = i;
     }
   return activeUpsNameIndex;
