@@ -17,11 +17,20 @@
 
 #include "knutprefdlg.h"
 #include "knutvardata.h"
-
 #include "knutfrontpanel.h"
+#include "knutdock.h"
 
 #include <kiconloader.h>
+
 #include <qlayout.h>
+#include <qgroupbox.h>
+#include <qbuttongroup.h>
+#include <qradiobutton.h>
+#include <qfont.h>
+#include <qlabel.h>
+#include <qcheckbox.h>
+#include <qspinbox.h>
+ 
 
 #include <stdio.h>
 //#include <iostream>
@@ -33,9 +42,8 @@ void KNutPrefDlg::initSetting () {
   QFrame *page = addPage( i18n("Setting"),i18n("Main Setting"),DesktopIcon("misc"));
   QVBoxLayout *setTopLayout = new QVBoxLayout( page, 10, spacingHint (), "setTopLayout" );
 
-//nahradime boxem
   QGroupBox *dataBox = new QGroupBox (page ,"dataBox");
-  QGridLayout *dataLayout = new QGridLayout (dataBox,3,2,spacingHint());
+  QGridLayout *dataLayout = new QGridLayout (dataBox,4,2,spacingHint());
   dataBox->setFrameStyle(QFrame::NoFrame);
   setTopLayout->addWidget(dataBox);
 
@@ -45,7 +53,7 @@ void KNutPrefDlg::initSetting () {
   xfer = new QCheckBox (i18n("&Use High-Low XFER"),VFGroup,"xfer");
 
   QLabel *label1 = new QLabel(i18n("Number of columns :"),dataBox,"label1");
-  numberOfColumns = new QSpinBox(MIN_COLS,MAX_COLS,1,dataBox);
+  numberOfColumns = new QSpinBox(knc::MinCols,knc::MaxCols,1,dataBox);
 
   QLabel *label2 = new QLabel(i18n("Use custom background color"),dataBox,"label2");
   checkBoxCbc = new QCheckBox ("",dataBox,"checboxcbc");
@@ -59,14 +67,19 @@ void KNutPrefDlg::initSetting () {
 
   checkBoxAys = new QCheckBox ("",dataBox,"checboxaus");
 
+  QLabel *label5 = new QLabel(i18n("Use Main window when program started :"),dataBox,"label5");
+
+  checkBoxMW = new QCheckBox ("",dataBox,"checboxaus");
+  
+
   voltageGroup = new QButtonGroup(i18n("Nominal Input Voltage"),VFGroup,"voltageGroup");
-  QGridLayout *voltLayout = new QGridLayout (voltageGroup, 4 , 1,spacingHint () );
+  QGridLayout *voltLayout = new QGridLayout (voltageGroup, 3 , 1,spacingHint () );
 
   vRadioButton1 = new QRadioButton(i18n("&230 V"), voltageGroup, "vRadioButton1" );
   vRadioButton2 = new QRadioButton(i18n("&120 V"), voltageGroup, "vRadioButton2" );
 
   frequencyGroup = new QButtonGroup(i18n("Nominal Input Frequency"),VFGroup,"frequencyGroup");
-  QGridLayout *freqLayout = new QGridLayout (frequencyGroup, 4 , 1,spacingHint () );
+  QGridLayout *freqLayout = new QGridLayout (frequencyGroup, 3 , 1,spacingHint () );
 
   fRadioButton1 = new QRadioButton(i18n("&50 Hz"), frequencyGroup, "fRadioButton1" );
   fRadioButton2 = new QRadioButton(i18n("&60 Hz"), frequencyGroup, "fRadioButton2" );
@@ -83,17 +96,20 @@ void KNutPrefDlg::initSetting () {
   dataLayout->addWidget (label4,3,0);
   dataLayout->addWidget (checkBoxAys,3,1);
 
+  dataLayout->addWidget (label5,4,0);
+  dataLayout->addWidget (checkBoxMW,4,1);
+
   dataLayout->setColStretch(1,5);
 
   voltLayout->addRowSpacing (0 ,fontMetrics().lineSpacing() );
   voltLayout->addWidget ( vRadioButton1,1,0 );
   voltLayout->addWidget ( vRadioButton2,2,0 );
-  voltLayout->addRowSpacing (3 ,fontMetrics().lineSpacing() );
+//  voltLayout->addRowSpacing (3 ,fontMetrics().lineSpacing() );
 
   freqLayout->addRowSpacing (0 ,fontMetrics().lineSpacing() );
   freqLayout->addWidget ( fRadioButton1,1,0 );
   freqLayout->addWidget ( fRadioButton2,2,0 );
-  freqLayout->addRowSpacing (3 ,fontMetrics().lineSpacing() );
+//  freqLayout->addRowSpacing (3 ,fontMetrics().lineSpacing() );
 
   setTopLayout->addWidget (VFGroup,10);
   setVoltFreqLayout->addRowSpacing (0 ,fontMetrics().lineSpacing() );
@@ -108,15 +124,16 @@ void KNutPrefDlg::initSetting () {
   numberOfColumns->setValue(prefData->countCols);
   BGButton->setColor(prefData->mainBackgroundColor);  // nastavime barvu pozadi
   checkBoxAys->setChecked(prefData->areYouSure);
+  checkBoxMW->setChecked(prefData->useMainWindow);
 
   if (prefData->inputVoltage == 230)
-    vRadioButton1->setChecked( TRUE );
+    vRadioButton1->setChecked( true );
   else
-    vRadioButton2->setChecked( TRUE );
+    vRadioButton2->setChecked( true );
   if (prefData->inputFrequency == 50)
-    fRadioButton1->setChecked( TRUE );
+    fRadioButton1->setChecked( true );
   else
-    fRadioButton2->setChecked( TRUE );
+    fRadioButton2->setChecked( true );
 
   xfer->setChecked(prefData->lowHighXfer);
   voltageGroup->setEnabled(!prefData->lowHighXfer);
@@ -144,7 +161,7 @@ void KNutPrefDlg::initUps () {
   ListBox2->setMinimumSize (100,100);
 
   // naplnime listbox
-  for (int i=0; i < myUpsData->getCount (); i++) ListBox2->insertItem (*myUpsData->getName(i));
+  for (int i=0; i < myUpsData->getCount (); i++) ListBox2->insertItem (myUpsData->getName(i));
   // vlozime ListBox do horizontalniho Layoutu na prvni misto
   upsTopLayout->addWidget( ListBox2, 20 );
   // vytvorime vertikalni Layout a vlozime jej na druhe misto do hor. layoutu
@@ -167,6 +184,90 @@ void KNutPrefDlg::initUps () {
   connect (deleteButton,SIGNAL(clicked()),this,SLOT(slotDeleteUps()));
   }
 
+void KNutPrefDlg::initDock () {
+//  QFrame *page = addPage( i18n("Dock"),i18n("Docking Setting"),DesktopIcon("knutclient"));
+  QFrame *page = addPage( i18n("Dock"),i18n("Docking Setting"),DesktopIcon("kcmkicker"));
+  QVBoxLayout *setTopLayout = new QVBoxLayout( page, 10, spacingHint (), "setTopLayout" );
+
+  typeGroup = new QButtonGroup(i18n("Type of dock's showing"),page,"typeGroup");
+  QGridLayout *typeLayout = new QGridLayout (typeGroup,2,2,spacingHint());
+  setTopLayout->addWidget(typeGroup);
+
+
+  QGroupBox *infoBox = new QGroupBox (i18n("Items of tooltip"),page ,"infoBox");
+  QGridLayout *infoLayout = new QGridLayout (infoBox,8,1,spacingHint());
+  setTopLayout->addWidget(infoBox);
+
+  QGridLayout *colorLayout = new QGridLayout (10,1,spacingHint(),"colorLayout");
+  setTopLayout->addLayout(colorLayout);
+
+
+  iconRadioButton1 = new QRadioButton(i18n("&Picture"), typeGroup, "iconRadioButton1" );
+  iconRadioButton2 = new QRadioButton(i18n("&General"), typeGroup, "iconRadioButton2" );
+
+  
+  checkBoxTTMFR = new QCheckBox (i18n("M&anufacturer"),infoBox);
+  checkBoxTTMFR->setChecked((prefData->toolTipFlags) & knc::TTMFR);
+
+  checkBoxTTModel = new QCheckBox (i18n("M&odel"),infoBox);
+  checkBoxTTModel->setChecked((prefData->toolTipFlags) & knc::TTModel);
+
+  checkBoxTTSerial = new QCheckBox (i18n("&Serial"),infoBox);
+  checkBoxTTSerial->setChecked((prefData->toolTipFlags) & knc::TTSerial);
+
+  checkBoxTTFirm = new QCheckBox (i18n("&Firm. rev."),infoBox);
+  checkBoxTTFirm->setChecked((prefData->toolTipFlags) & knc::TTFirm);
+
+  checkBoxTTRun = new QCheckBox (i18n("&Runtime"),infoBox);
+  checkBoxTTRun->setChecked((prefData->toolTipFlags) & knc::TTRun);
+
+  checkBoxTTCharge = new QCheckBox (i18n("&Battery Charge"),infoBox);
+  checkBoxTTCharge->setChecked((prefData->toolTipFlags) & knc::TTCharge);
+
+  checkBoxTTLoad = new QCheckBox (i18n("&UPS Load"),infoBox);
+  checkBoxTTLoad->setChecked((prefData->toolTipFlags) & knc::TTLoad);
+  
+  
+  QLabel *label1 = new QLabel(i18n("Use custom icon's background color"),page,"label1");
+  checkBoxCbi = new QCheckBox ("",page,"checboxcbpc");
+
+  label12 = new QLabel(i18n("Color of icon's background :"),page,"label12");
+  BGIButton = new KColorButton (page);
+
+  typeLayout->addRowSpacing (0 ,fontMetrics().lineSpacing() );
+  typeLayout->addWidget ( iconRadioButton1,1,0 );
+  typeLayout->addWidget ( iconRadioButton2,2,0 );
+
+  if (prefData->typeOfKIcon == knc::pictureKI)
+    iconRadioButton1->setChecked( true );
+  if (prefData->typeOfKIcon == knc::generalKI)
+    iconRadioButton2->setChecked( true );
+  
+  infoLayout->addRowSpacing (0 ,fontMetrics().lineSpacing() );
+  infoLayout->addWidget ( checkBoxTTMFR ,1,0);
+  infoLayout->addWidget ( checkBoxTTModel ,2,0);
+  infoLayout->addWidget ( checkBoxTTSerial ,3,0);
+  infoLayout->addWidget ( checkBoxTTFirm ,4,0);
+  infoLayout->addWidget ( checkBoxTTRun ,5,0);
+  infoLayout->addWidget ( checkBoxTTCharge ,6,0);
+  infoLayout->addWidget ( checkBoxTTLoad ,7,0);
+  
+  colorLayout->addWidget (label1,0,0);
+  colorLayout->addWidget (checkBoxCbi,0,1);
+  colorLayout->addWidget (label12,1,0);
+  colorLayout->addWidget (BGIButton,1,1);
+
+  checkBoxCbi->setChecked(prefData->customKIconColor);
+  BGIButton->setColor(prefData->kIconBackgroundColor);
+  BGIButton->setEnabled(prefData->customKIconColor);
+  label12->setEnabled(prefData->customKIconColor);
+
+  
+  setTopLayout->addStretch( 20 );
+
+  connect (checkBoxCbi,SIGNAL(toggled(bool)),this,SLOT(slotUseCustomBIconColor(bool)));
+  }
+  
 
 void KNutPrefDlg::initPanel () {
   QFrame *page = addPage( i18n("Panel"),i18n("Panel Setting"),DesktopIcon("panel_settings"));
@@ -183,42 +284,41 @@ void KNutPrefDlg::initPanel () {
 
   // vytvorime widgety - Nazev Zatrhavaci box
   checkBoxOver = new QCheckBox (i18n("UPS &Overload"),infoBox);
-  checkBoxOver->setChecked((prefData->panelFlags) & PB_OVER);
+  checkBoxOver->setChecked((prefData->panelFlags) & knc::PBOver);
 
   checkBoxBL = new QCheckBox (i18n("UPS &Battery low"),infoBox);
-  checkBoxBL->setChecked((prefData->panelFlags) & PB_BATT_LOW);
+  checkBoxBL->setChecked((prefData->panelFlags) & knc::PBBattLow);
 
   checkBoxRB = new QCheckBox (i18n("R&eplace battery"),infoBox);
-  checkBoxRB->setChecked((prefData->panelFlags) & PB_REP_BATT);
+  checkBoxRB->setChecked((prefData->panelFlags) & knc::PBRepBatt);
 
   checkBoxCal = new QCheckBox (i18n("Ups &calibration"),infoBox);
-  checkBoxCal->setChecked((prefData->panelFlags) & PB_CAL);
+  checkBoxCal->setChecked((prefData->panelFlags) & knc::PBCal);
 
   checkBoxMFRM = new QCheckBox (i18n("&Manufac. + Model"),infoBox);
-  checkBoxMFRM->setChecked((prefData->panelFlags) & PB_MFR_MOD);
+  checkBoxMFRM->setChecked((prefData->panelFlags) & knc::PBMFRMod);
 
   checkBoxMFR = new QCheckBox (i18n("M&anufacturer"),infoBox);
-  checkBoxMFR->setChecked((prefData->panelFlags) & PB_MFR);
+  checkBoxMFR->setChecked((prefData->panelFlags) & knc::PBMFR);
 
   checkBoxModel = new QCheckBox (i18n("M&odel"),infoBox);
-  checkBoxModel->setChecked((prefData->panelFlags) & PB_MODEL);
+  checkBoxModel->setChecked((prefData->panelFlags) & knc::PBModel);
 
   checkBoxSerial = new QCheckBox (i18n("&Serial"),infoBox);
-  checkBoxSerial->setChecked((prefData->panelFlags) & PB_SERIAL);
+  checkBoxSerial->setChecked((prefData->panelFlags) & knc::PBSerial);
 
   checkBoxFirm = new QCheckBox (i18n("&Firm. rev."),infoBox);
-  checkBoxFirm->setChecked((prefData->panelFlags) & PB_FIRM);
+  checkBoxFirm->setChecked((prefData->panelFlags) & knc::PBFirm);
 
   checkBoxRun = new QCheckBox (i18n("&Runtime"),infoBox);
-  checkBoxRun->setChecked((prefData->panelFlags) & PB_RUN);
+  checkBoxRun->setChecked((prefData->panelFlags) & knc::PBRun);
 
 
   QLabel *label1 = new QLabel(i18n("Use custom background color"),page,"label1");
   checkBoxCbpc = new QCheckBox ("",page,"checboxcbpc");
 
-  label4 = new QLabel(i18n("Color of background :"),page,"label2");
+  label4 = new QLabel(i18n("Color of background :"),page,"label4");
   BGPButton = new KColorButton (page);
-//  BGPButton->setColor (prefData->mainBackgroundColor);
 
 // Vlozime widgety
   infoLayout->addWidget ( checkBoxOver, 0,0);
@@ -242,6 +342,7 @@ void KNutPrefDlg::initPanel () {
   checkBoxCbpc->setChecked(prefData->customBPanelColor);
   BGPButton->setColor(prefData->mPanelBackgroundColor);
   BGPButton->setEnabled(prefData->customBPanelColor);
+  label4->setEnabled(prefData->customBPanelColor);
   label3->setEnabled(prefData->customBPanelColor);
   connect (checkBoxCbpc,SIGNAL(toggled(bool)),this,SLOT(slotUseCustomBPanelColor(bool)));
 
@@ -296,7 +397,7 @@ void KNutPrefDlg::initAnalog () {
   BGAButton = new KColorButton (page);
   QLabel *label12 = new QLabel(i18n("Use custom other colors"),page,"label12");
   checkBoxCoac = new QCheckBox ("",page,"checboxcoac");
-  label6 = new QLabel(i18n("Color of finger :"),page,"label6");
+  label6 = new QLabel(i18n("Color of pointer :"),page,"label6");
   AFingerButton = new KColorButton (page);
   label7 = new QLabel(i18n("Color of OK range :"),page,"label7");
   AOKButton = new KColorButton (page);
@@ -359,21 +460,23 @@ void KNutPrefDlg::initAnalog () {
   }
 
 
-KNutPrefDlg::KNutPrefDlg(KNutUpsData* upsData, KNutVarData* analogData, SettingDataDef* settingData, QString upsName, QWidget* parent,  const char* name, bool modal)
+KNutPrefDlg::KNutPrefDlg(KNutUpsData* const upsData, KNutVarData* const analogData, SettingDataDef* const settingData, const QString upsName, QWidget* parent,  const char* name,const bool modal)
             : KDialogBase(IconList, i18n("Preferences"),Help|Default|Apply|Ok|Cancel,Ok, parent, name, modal, true), activeUpsName (upsName) {
+
   setName( "UpsMemberDlg" );
 
   myUpsData = upsData;
   myAnalogData=analogData;
-  checked = FALSE; // neni zadna zmena na definici UPS
-  checkedActiveUps = FALSE; // neni provedena zmena aktivni UPS
+  checked = false; // neni zadna zmena na definici UPS
+  checkedActiveUps = false; // neni provedena zmena aktivni UPS
   prefData=settingData;
 
-  initSetting ();
+  initSetting();
   initUps();
   initPanel();
   initFonts();
-  initAnalog(); // az v dalsi verzi
+  initAnalog();
+  initDock(); // from 0.8 version
   setMinimumSize (450, 300);
   }
 
@@ -391,6 +494,12 @@ void KNutPrefDlg::slotUseCustomBColor(bool enable) {
   label3->setEnabled(enable);
   }
 
+void KNutPrefDlg::slotUseCustomBIconColor(bool enable) {
+  BGIButton->setEnabled(enable);
+  label12->setEnabled(enable);
+  }
+
+  
 void KNutPrefDlg::slotUseCustomBPanelColor(bool enable) {
   BGPButton->setEnabled(enable);
   label4->setEnabled(enable);
@@ -421,13 +530,11 @@ void KNutPrefDlg::slotUseCustomOAnalogColor(bool enable) {
 void KNutPrefDlg::slotChangeSettingFont(int index) {
   if (settingFont != index) {
   // vybirame jiny font
-  if (settingFont == MAIN_PANEL_FONT)
-    {
+  if (settingFont == MAIN_PANEL_FONT) {
      mPanelFont=fontWidget->font();
      fontWidget->setFont(aPanelFont);
     }
-  else
-    {
+  else {
     aPanelFont=fontWidget->font();
     fontWidget->setFont(mPanelFont);
     }
@@ -441,10 +548,10 @@ void KNutPrefDlg::slotDeleteUps() {
   if (ListBox2->currentItem() != -1)	{
     // smazeme policko
     int ukListBox = ListBox2->currentItem();
-    if ( activeUpsName == ListBox2->currentText() ) checkedActiveUps = TRUE;
+    if ( activeUpsName == ListBox2->currentText() ) checkedActiveUps = true;
     myUpsData->deleteName(ukListBox);
     ListBox2->removeItem(ukListBox);
-    checked = TRUE;
+    checked = true;
     // pokud smazeme aktivni UPS nsatavime checkedActiveUps
     }
   }
@@ -452,9 +559,9 @@ void KNutPrefDlg::slotDeleteUps() {
 
 void KNutPrefDlg::slotEditUps() {
   if (ListBox2->currentItem() != -1)	{
-    UpsInfo upsPref;
+    upsRecord upsPref;
     // Vytvorime dialog
-    newUpsDlg = new KNutNewUpsDlg(myUpsData,myAnalogData,FALSE);
+    newUpsDlg = new KNutNewUpsDlg(myUpsData,myAnalogData,false);
     // precteme zaznam
     myUpsData->get(ListBox2->currentItem(),upsPref);
     // nastavime parametry pro edit
@@ -468,9 +575,9 @@ void KNutPrefDlg::slotEditUps() {
       myUpsData->put(ListBox2->currentItem(),upsPref);
       // opravime data v okenku
       ListBox2->changeItem(upsPref.name,ListBox2->currentItem());
-      checked = TRUE;
+      checked = true;
       // pokud zmenime aktivni UPS nsatavime checkedActiveUps
-      if ( activeUpsName == ListBox2->currentText() ) checkedActiveUps = TRUE;
+      if ( activeUpsName == ListBox2->currentText() ) checkedActiveUps = true;
       }
     delete newUpsDlg;
     }
@@ -478,7 +585,7 @@ void KNutPrefDlg::slotEditUps() {
 
 
 void KNutPrefDlg::slotNewUps () {
-  UpsInfo upsPref;
+  upsRecord upsPref;
   // Zalozime novy zdroj
   newUpsDlg = new KNutNewUpsDlg(myUpsData,myAnalogData);
   int result = newUpsDlg->exec();
@@ -491,8 +598,8 @@ void KNutPrefDlg::slotNewUps () {
     // pridame data do okenka
     ListBox2->insertItem(upsPref.name);
     // pokud pridame prvni prekreslime hlavni okno
-    checked = TRUE;
-    if (myUpsData->getCount() ==1 ) checkedActiveUps = TRUE;
+    checked = true;
+    if (myUpsData->getCount() ==1 ) checkedActiveUps = true;
     }
   delete newUpsDlg;
   }
@@ -511,70 +618,81 @@ void KNutPrefDlg::slotApply() {
 
  // MainPage
   if (prefData->countCols != numberOfColumns->value()) {
-    changeSetting += CHANGE_COUNT_COLS;  // nastavime pocet sloupcu
+    changeSetting += knc::ChangeCountCols;  // nastavime pocet sloupcu
     prefData->countCols = numberOfColumns->value();  // nastavime pocet sloupcu
     }
 
   if (prefData->customBColor != checkBoxCbc->isChecked()) {
     prefData->customBColor = checkBoxCbc->isChecked();
-    changeSetting += CHANGE_CUSTOM_BCOLOR;
+    changeSetting += knc::ChangeCustomBColor;
     }
                            
   if (prefData->mainBackgroundColor != BGButton->color()) {
-    changeSetting += CHANGE_MBCOLOR;
+    changeSetting += knc::ChangeMBColor;
     prefData->mainBackgroundColor = BGButton->color();  // nastavime barvu pozadi
     }
          
-  // ovlivnuje jen ukonceni programu nei duvod pro ChangeSetting
-  prefData->areYouSure = checkBoxAys->isChecked();
+  // ovlivnuje jen ukonceni programu, meurcujeme type ChangeSetting
+  if (prefData->areYouSure != checkBoxAys->isChecked()) {
+    prefData->areYouSure = checkBoxAys->isChecked();
+    changeSetting = changeSetting | knc::ChangeSomeThing;
+    }
 
+  // ovlivnuje jen pristi start
+  if (prefData->useMainWindow != checkBoxMW->isChecked()) {
+    prefData->useMainWindow = checkBoxMW->isChecked();
+    changeSetting = changeSetting | knc::ChangeSomeThing;
+    }
+    
   int newInputVoltage, newInputFrequency;
   if ( vRadioButton1->isChecked()) newInputVoltage = 230; else newInputVoltage = 120;
   if ( fRadioButton1->isChecked()) newInputFrequency = 50; else newInputFrequency = 60;
 
   if (prefData->inputVoltage != newInputVoltage) {
     prefData->inputVoltage = newInputVoltage;
-    changeSetting += CHANGE_VOLTAGE;
+    changeSetting += knc::ChangeVoltage;
     }
 
   if (prefData->inputFrequency != newInputFrequency) {
     prefData->inputFrequency = newInputFrequency;
-    changeSetting += CHANGE_FREQUENCY;
+    changeSetting += knc::ChangeFrequency;
     }
 
- if (prefData->lowHighXfer != xfer->isChecked()) changeSetting += CHANGE_XFER;
+ if (prefData->lowHighXfer != xfer->isChecked()) changeSetting += knc::ChangeXFer;
  prefData->lowHighXfer = xfer->isChecked();
 
     //Ups page
-  if ( checkedActiveUps ) { // zmenea aktivni UPS
-    changeSetting += CHANGE_UPS_SETTING;
+  if ( checkedActiveUps ) { // zmena aktivni UPS
+    changeSetting += knc::ChangeUpsSetting;
     }
+  else {
+    if (checked) changeSetting += knc::ChangeUpsCount;
+    }
+  // panel Page
+  unsigned int prefPanelFlags = 3;
+  if (checkBoxOver->isChecked()) prefPanelFlags += knc::PBOver;
+  if (checkBoxBL->isChecked()) prefPanelFlags += knc::PBBattLow;
+  if (checkBoxRB->isChecked()) prefPanelFlags += knc::PBRepBatt;
+  if (checkBoxCal->isChecked()) prefPanelFlags += knc::PBCal;
+  if (checkBoxMFRM->isChecked()) prefPanelFlags += knc::PBMFRMod;
+  if (checkBoxMFR->isChecked()) prefPanelFlags += knc::PBMFR;
+  if (checkBoxModel->isChecked()) prefPanelFlags += knc::PBModel;
+  if (checkBoxSerial->isChecked()) prefPanelFlags += knc::PBSerial;
+  if (checkBoxFirm->isChecked()) prefPanelFlags += knc::PBFirm;
+  if (checkBoxRun->isChecked()) prefPanelFlags += knc::PBRun;
 
-    // panel Page
-    unsigned int prefPanelFlags = 3;
-    if (checkBoxOver->isChecked()) prefPanelFlags += PB_OVER;
-    if (checkBoxBL->isChecked()) prefPanelFlags += PB_BATT_LOW;
-    if (checkBoxRB->isChecked()) prefPanelFlags += PB_REP_BATT;
-    if (checkBoxCal->isChecked()) prefPanelFlags += PB_CAL;
-    if (checkBoxMFRM->isChecked()) prefPanelFlags += PB_MFR_MOD;
-    if (checkBoxMFR->isChecked()) prefPanelFlags += PB_MFR;
-    if (checkBoxModel->isChecked()) prefPanelFlags += PB_MODEL;
-    if (checkBoxSerial->isChecked()) prefPanelFlags += PB_SERIAL;
-    if (checkBoxFirm->isChecked()) prefPanelFlags += PB_FIRM;
-    if (checkBoxRun->isChecked()) prefPanelFlags += PB_RUN;
-
-    if (prefData->panelFlags != prefPanelFlags) {
-      prefData->panelFlags = prefPanelFlags;
-      changeSetting += CHANGE_MAIN_PANEL_SETTING;
-      }
+  if (prefData->panelFlags != prefPanelFlags) {
+    prefData->panelFlags = prefPanelFlags;
+    changeSetting += knc::ChangeMainPanelSetting;
+    }
 
   if (prefData->customBPanelColor != checkBoxCbpc->isChecked()) {
     prefData->customBPanelColor = checkBoxCbpc->isChecked();
-    changeSetting += CHANGE_CUSTOM_MPANEL_BCOLOR;
+    changeSetting += knc::ChangeCustomMPanelBColor;
     }
 
   if (prefData->mPanelBackgroundColor != BGPButton->color()) {
-    changeSetting += CHANGE_MPBCOLOR;
+    changeSetting += knc::ChangeMPBColor;
     prefData->mPanelBackgroundColor = BGPButton->color();  // nastavime barvu pozadi
     }
 
@@ -596,13 +714,13 @@ void KNutPrefDlg::slotApply() {
          // prejdeme na uzivatelske fonty
          prefData->aPanelFont = aPanelFont;
          prefData->mPanelFont = mPanelFont;
-         changeSetting += CHANGE_ANALOG_FONT;
-         changeSetting += CHANGE_PANEL_FONT;
+         changeSetting += knc::ChangeAnalogFont;
+         changeSetting += knc::ChangePanelFont;
          }
        else {
          // pouzijeme systemove fonty
-         changeSetting += CHANGE_ANALOG_FONT;
-         changeSetting += CHANGE_PANEL_FONT;
+         changeSetting += knc::ChangeAnalogFont;
+         changeSetting += knc::ChangePanelFont;
          }
       }
     else {
@@ -610,11 +728,11 @@ void KNutPrefDlg::slotApply() {
         // otestujeme zda se zmenili nase fonty
         if (aPanelFont != prefData->aPanelFont) {
           prefData->aPanelFont = aPanelFont;
-          changeSetting += CHANGE_ANALOG_FONT;
+          changeSetting += knc::ChangeAnalogFont;
           }
         if (mPanelFont != prefData->mPanelFont) {
           prefData->mPanelFont = mPanelFont;
-          changeSetting += CHANGE_PANEL_FONT;
+          changeSetting += knc::ChangePanelFont;
           }
         }
       }
@@ -622,17 +740,17 @@ void KNutPrefDlg::slotApply() {
 
   if (prefData->customBAnalogColor != checkBoxCbac->isChecked()) {
     prefData->customBAnalogColor = checkBoxCbac->isChecked();
-    changeSetting += CHANGE_CUSTOM_APANEL_BCOLOR;
+    changeSetting += knc::ChangeCustomAPanelBColor;
     }
 
   if (prefData->aPanelBackgroundColor != BGAButton->color()) {
-    changeSetting += CHANGE_APBCOLOR;
+    changeSetting += knc::ChangeAPBColor;
     prefData->aPanelBackgroundColor = BGAButton->color();  // nastavime barvu pozadi
     }
 
   if (prefData->customOAnalogColor != checkBoxCoac->isChecked()) {
     prefData->customOAnalogColor = checkBoxCoac->isChecked();
-    changeSetting += CHANGE_CUSTOM_APANEL_OCOLOR;
+    changeSetting += knc::ChangeCustomAPanelOColor;
     }
 
   if ((prefData->analogFingerColor != AFingerButton->color()) ||
@@ -641,7 +759,7 @@ void KNutPrefDlg::slotApply() {
       (prefData->analogErrorColor != AErrorButton->color()) ||
       (prefData->analogScaleColor != AScaleButton->color()) ||
       (prefData->analogFontColor != AFontButton->color())) {
-    changeSetting += CHANGE_APOCOLOR;
+    changeSetting += knc::ChangeAPOColor;
     prefData->analogFingerColor = AFingerButton->color();  // nastavime barvu rucicky
     prefData->analogOKColor = AOKButton->color();  // nastavime barvu ok
     prefData->analogWarnningColor = AWarnningButton->color();  // nastavime barvu varovano
@@ -650,8 +768,41 @@ void KNutPrefDlg::slotApply() {
     prefData->analogFontColor = AFontButton->color();  // nastavime barvu textu
     }
     
+  // Kicker Icon page
 
-    
+  int stateKIcon;
+  if (iconRadioButton1->isChecked()) stateKIcon = knc::pictureKI;
+  else stateKIcon = knc::generalKI;
+  if (prefData->typeOfKIcon != stateKIcon) {
+    if (iconRadioButton1->isChecked()) prefData->typeOfKIcon = knc::pictureKI;
+    if (iconRadioButton2->isChecked()) prefData->typeOfKIcon = knc::generalKI;
+    changeSetting += knc::ChangeTypeOfKIcon;
+    }
+
+  if (prefData->customKIconColor != checkBoxCbi->isChecked()) {
+    prefData->customKIconColor = checkBoxCbi->isChecked();
+    changeSetting += knc::ChangeCustomKIconColor;
+    }
+
+  if (prefData->kIconBackgroundColor != BGIButton->color()) {
+    changeSetting += knc::ChangeKIconBColor;
+    prefData->kIconBackgroundColor = BGIButton->color();  // nastavime barvu pozadi
+    }
+
+  unsigned int prefToolTipFlags = 0;
+  if (checkBoxTTMFR->isChecked()) prefToolTipFlags += knc::TTMFR;
+  if (checkBoxTTModel->isChecked()) prefToolTipFlags += knc::TTModel;
+  if (checkBoxTTSerial->isChecked()) prefToolTipFlags += knc::TTSerial;
+  if (checkBoxTTFirm->isChecked()) prefToolTipFlags += knc::TTFirm;
+  if (checkBoxTTRun->isChecked()) prefToolTipFlags += knc::TTRun;
+  if (checkBoxTTCharge->isChecked()) prefToolTipFlags += knc::TTCharge;
+  if (checkBoxTTLoad->isChecked()) prefToolTipFlags += knc::TTLoad;
+
+  if (prefData->toolTipFlags != prefToolTipFlags) {
+    prefData->toolTipFlags = prefToolTipFlags;
+    changeSetting += knc::ChangeToolTip;
+    }
+            
   if (changeSetting)  emit signalChangeConfig( changeSetting );
   }
 
@@ -659,23 +810,24 @@ void KNutPrefDlg::slotApply() {
 void KNutPrefDlg::slotDefault() {
   switch (activePageIndex()) {
     case mainSettingPage:
-      numberOfColumns->setValue( DEFAULT_COUNT_COLS );
+      numberOfColumns->setValue( knc::DefaultCountCols );
       BGButton->setColor(DEFAULT_BG_COLOR);
-      checkBoxAys->setChecked ( FALSE );
-      vRadioButton1->setChecked( TRUE );
-      fRadioButton1->setChecked( TRUE );
-      xfer->setChecked( FALSE );
+      checkBoxAys->setChecked ( false );
+      checkBoxMW->setChecked ( true );
+      vRadioButton1->setChecked( true );
+      fRadioButton1->setChecked( true );
+      xfer->setChecked( false );
       break;
     case panelSettingPage:
-      checkBoxOver->setChecked(DEFAULT_PANEL_FLAGS & PB_OVER);
-      checkBoxBL->setChecked(DEFAULT_PANEL_FLAGS & PB_BATT_LOW);
-      checkBoxRB->setChecked(DEFAULT_PANEL_FLAGS & PB_REP_BATT);
-      checkBoxCal->setChecked(DEFAULT_PANEL_FLAGS & PB_CAL);
-      checkBoxMFRM->setChecked(DEFAULT_PANEL_FLAGS & PB_MFR_MOD);
-      checkBoxMFR->setChecked(DEFAULT_PANEL_FLAGS & PB_MFR);
-      checkBoxModel->setChecked(DEFAULT_PANEL_FLAGS & PB_MODEL);
-      checkBoxSerial->setChecked(DEFAULT_PANEL_FLAGS & PB_SERIAL);
-      checkBoxFirm->setChecked(DEFAULT_PANEL_FLAGS & PB_FIRM);
+      checkBoxOver->setChecked(knc::DefaultPanelFlags & knc::PBOver);
+      checkBoxBL->setChecked(knc::DefaultPanelFlags & knc::PBBattLow);
+      checkBoxRB->setChecked(knc::DefaultPanelFlags & knc::PBRepBatt);
+      checkBoxCal->setChecked(knc::DefaultPanelFlags & knc::PBCal);
+      checkBoxMFRM->setChecked(knc::DefaultPanelFlags & knc::PBMFRMod);
+      checkBoxMFR->setChecked(knc::DefaultPanelFlags & knc::PBMFR);
+      checkBoxModel->setChecked(knc::DefaultPanelFlags & knc::PBModel);
+      checkBoxSerial->setChecked(knc::DefaultPanelFlags & knc::PBSerial);
+      checkBoxFirm->setChecked(knc::DefaultPanelFlags & knc::PBFirm);
       checkBoxCbpc->setChecked(false);
       BGAButton->setColor(DEFAULT_BG_COLOR);
       break;
@@ -693,5 +845,19 @@ void KNutPrefDlg::slotDefault() {
       AScaleButton->setColor(DEFAULT_SCALE_COLOR);
       AFontButton->setColor(DEFAULT_FONT_COLOR);
       break;
+   case kickerSettingPage:
+      checkBoxCbi->setChecked(false);
+      BGAButton->setColor(DEFAULT_KICON_COLOR);
+      checkBoxTTMFR->setChecked(knc::DefaultToolTipFlags & knc::TTMFR);
+      checkBoxTTModel->setChecked(knc::DefaultToolTipFlags & knc::TTModel);
+      checkBoxTTSerial->setChecked(knc::DefaultToolTipFlags & knc::TTSerial);
+      checkBoxTTFirm->setChecked(knc::DefaultToolTipFlags & knc::TTFirm);
+      checkBoxTTRun->setChecked(knc::DefaultToolTipFlags & knc::TTRun);
+      checkBoxTTCharge->setChecked(knc::DefaultToolTipFlags & knc::TTCharge);
+      checkBoxTTLoad->setChecked(knc::DefaultToolTipFlags & knc::TTLoad);
+      iconRadioButton1->setChecked( true );
+      break;
     }
   }
+
+#include "knutprefdlg.moc"
