@@ -32,20 +32,12 @@
 
 #include <qvariant.h>
 #include <qlayout.h>
-//#include <qlabel.h>
 #include <qvaluelist.h>
 //#include <qpixmap.h>
+//#include <qlabel.h>
 
 
-#if defined  (KDE_VERSION_MAJOR)
-  #if KDE_VERSION_MAJOR >= 3
-    #include <qvaluevector.h>
-  #else
-    #include <qvaluelist.h>
-  #endif
-#else
-  #include <qvaluelist.h>
-#endif
+#include <qvaluevector.h>
 
 class QLabel;
 class QPixmap;
@@ -62,7 +54,7 @@ class QString;
  * pro urcenou UPS-ku
  * @author Daniel Prynych
  * @short NUT show UPS vars
- * @version 0.3.1
+ * @version 0.3.2
 */
 class KNutPrintUpsVar : public KDialogBase  {
 
@@ -108,36 +100,14 @@ protected:
 
   KPushButton* reloadButton;
 
-#if defined  (KDE_VERSION_MAJOR)
-  #if KDE_VERSION_MAJOR >= 3
-    struct dataVar {
-      QString myName;
-      KListViewItem* myValue;
-      };
-    QValueVector<dataVar> dataList;
-    KListViewItem* ROVarsList;
-    KListViewItem* RWVarsList;
-    KListViewItem* ICommList;
-  #else
-    struct dataVar {
-      QString myName;
-      QListViewItem* myValue;
-      };
-    QValueList<dataVar> dataList;
-    QListViewItem* ROVarsList;
-    QListViewItem* RWVarsList;
-    QListViewItem* ICommList;
-  #endif
-#else
   struct dataVar {
     QString myName;
-    QListViewItem* myValue;
+    KListViewItem* myValue;
     };
-  QValueList<dataVar> dataList;
-  QListViewItem* ROVarsList;
-  QListViewItem* RWVarsList;
-  QListViewItem* ICommList;
-#endif
+  QValueVector<dataVar> dataList;
+  KListViewItem* ROVarsList;
+  KListViewItem* RWVarsList;
+  KListViewItem* ICommList;
 
   QFrame *page;
   KListView* table;
@@ -147,7 +117,7 @@ protected:
 
   bool upsConnectOk;
 
-// protected functions
+/********** protected functions ****************/
   
 /**
  * @internal
@@ -159,15 +129,8 @@ protected:
  *
  * @since  0.2.1
  **/
-#if defined  (KDE_VERSION_MAJOR)
-  #if KDE_VERSION_MAJOR >= 3
     KListViewItem* addListItem (KListViewItem* table, QString varName, QString value);
-  #else
-    QListViewItem* addListItem (QListViewItem* table, QString varName, QString value);
-  #endif
-#else
-  QListViewItem* addListItem (QListViewItem* table, QString varName, QString value);
-#endif
+
 /**
  * @internal
  * Zjisti existenci jmena ve vetvi stromu
@@ -177,15 +140,7 @@ protected:
  *
  * @since  0.2
  **/
-#if defined  (KDE_VERSION_MAJOR)
-  #if KDE_VERSION_MAJOR >= 3
     KListViewItem* existListItem (KListViewItem* listItem, QString name);
-  #else
-    QListViewItem* existListItem (QListViewItem* listItem, QString name);
-  #endif
-#else
-  QListViewItem* existListItem (QListViewItem* listItem, QString name);
-#endif
   
 protected slots:
 
