@@ -138,15 +138,7 @@ void KNutRWVar::slotDefault () {
   QString varName = rWVarBox->currentText();
   if (!( error = myUpsNet->readVars(varName,myStructVar))) {
     if (myStructVar.upsValueType) valueVarLine->setText(myStructVar.upsValue);
-    #if defined  (KDE_VERSION_MAJOR)
-      #if KDE_VERSION_MAJOR >= 3
-        else valueVarBox->setCurrentItem(myStructVar.upsValue);
-      #else
-        else valueVarBox->setCurrentItem(findItem(valueVarBox,myStructVar.upsValue));
-      #endif
-    #else
-      else valueVarBox->setCurrentItem(findItem(valueVarBox,myStructVar.upsValue));
-    #endif
+    else valueVarBox->setCurrentItem(myStructVar.upsValue);
     }
   else KNutVarData::showError (error);
   }  
@@ -174,16 +166,7 @@ void KNutRWVar::slotChangeVar(int item) {
       for (int i = 0 ; i < myStructVar.upsVarMax; i++)
         valueVarBox->insertItem(myUpsNet->readEnumValueVar(myStructVar.upsVarName,i+1));
       }
-
-      #if defined  (KDE_VERSION_MAJOR)
-        #if KDE_VERSION_MAJOR >= 3
-           valueVarBox->setCurrentItem(myStructVar.upsValue);
-        #else
-          valueVarBox->setCurrentItem(findItem(valueVarBox,myStructVar.upsValue));
-        #endif
-      #else
-        valueVarBox->setCurrentItem(findItem(valueVarBox,myStructVar.upsValue));
-      #endif
+    valueVarBox->setCurrentItem(myStructVar.upsValue);
     }
   }
 
@@ -192,7 +175,7 @@ void KNutRWVar::slotChangeVar(int item) {
 KNutRWVar::~KNutRWVar(){
 }
 
-bool KNutRWVar::upsOk (void) { return upsConnectOk; };
+bool KNutRWVar::upsOk (void) { return upsConnectOk; }
 
 
 void KNutRWVar::slotOk() {
