@@ -63,7 +63,7 @@ void KNutUpsData::deleteName (const int index) {
 }
 
 
-int KNutUpsData::getCount ( void ) { return countMembers; };
+int KNutUpsData::getCount ( void ) { return countMembers; }
 
 
 upsRecord* KNutUpsData::findName (const QString name) {
